@@ -27,6 +27,7 @@ def bootstrap(
     puppet_provisioning_role_permissions_boundary,
     cloud_formation_deploy_role_permissions_boundary,
     deploy_environment_compute_type,
+    spoke_deploy_environment_compute_type,
     deploy_num_workers,
     source_provider,
     owner,
@@ -226,6 +227,11 @@ def bootstrap(
                 "ParameterValue": deploy_environment_compute_type,
                 "UsePreviousValue": False,
             },
+            {
+                "ParameterKey": "SpokeDeployEnvironmentComputeType",
+                "ParameterValue": spoke_deploy_environment_compute_type,
+                "UsePreviousValue": False,
+            },
             {
                 "ParameterKey": "DeployNumWorkers",
                 "ParameterValue": str(deploy_num_workers),
